boost\_histogram.cpp
====================

.. automodule:: boost_histogram.cpp
   :members:
   :undoc-members:
   :show-inheritance:


.. include:: boost_histogram.cpp.axis.rst


boost\_histogram.cpp.accumulators
=================================

.. automodule:: boost_histogram.cpp.accumulators
   :members:
   :undoc-members:
   :show-inheritance:

boost\_histogram.cpp.algorithm
==============================

.. automodule:: boost_histogram.cpp.algorithm
   :members:
   :undoc-members:
   :show-inheritance:

boost\_histogram.cpp.storage
============================

.. automodule:: boost_histogram.cpp.storage
   :members:
   :undoc-members:
   :show-inheritance:

